PixaAnimationController class final

Controls frame scheduling for one or more controlled animated image streams.

Inheritance

Constructors

PixaAnimationController({PixaAnimationPlaybackState initialState = PixaAnimationPlaybackState.playing})
Creates an animation controller.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PixaAnimationPlaybackState
Current playback state.
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pause() → void
Pauses playback and keeps the currently displayed frame.
play() → void
Starts playback.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resume() → void
Resumes playback after pause.
stop() → void
Stops playback until play is called.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited