PixaCacheStats class final

Snapshot of Pixa cache behavior.

Constructors

PixaCacheStats({required int memoryEntries, required int memoryBytes, required int memoryHits, required int memoryMisses, required int diskHits, required int diskMisses, required int diskWrites, int diskCorruptionRecoveries = 0, required int evictions, int staleRevalidatesStarted = 0, int staleRevalidatesCompleted = 0, int staleRevalidatesFailed = 0, int staleRevalidatesSkipped = 0, int staleRevalidatesInFlight = 0, int processedMemoryEntries = 0, int processedMemoryBytes = 0, int processedMemoryHits = 0, int processedMemoryMisses = 0, int processedMemoryEvictions = 0, int processedDiskHits = 0, int processedDiskMisses = 0, int processedDiskStaleHits = 0, int processedDiskWrites = 0, int processedDiskCorruptionRecoveries = 0, int ownedBufferHandlesCreated = 0, int ownedBufferHandlesFreed = 0, int ownedBufferBytesExposed = 0, int progressSessionsCreated = 0, int progressSessionsFreed = 0, int progressEventsEmitted = 0, int progressEventsDropped = 0, int progressEventsDrained = 0, int progressPreviewBytesRetained = 0, int progressPreviewPayloadsDropped = 0, int progressPreviewBytesDropped = 0})
Creates a cache stats snapshot.
const

Properties

diskCorruptionRecoveries int
Corrupt encoded disk entries removed and recovered as cache misses.
final
diskHits int
Encoded disk cache hits.
final
diskMisses int
Encoded disk cache misses.
final
diskWrites int
Encoded disk cache writes.
final
encodedMemoryBytes int
Encoded source bytes retained in the shared memory LRU.
no setter
encodedMemoryEntries int
Encoded source entries retained in the shared memory LRU.
no setter
evictions int
Encoded memory evictions.
final
hashCode int
The hash code for this object.
no setterinherited
hitRate double
Hit rate across memory and disk cache lookups.
no setter
liveOwnedBufferHandles int
Owned runtime buffers that have not been released yet.
no setter
liveProgressSessions int
runtime progress sessions that have not been released yet.
no setter
memoryBytes int
Total bytes retained by the shared encoded and processed memory LRU.
final
memoryEntries int
Total entries retained by the shared encoded and processed memory LRU.
final
memoryHits int
Encoded memory cache hits.
final
memoryMisses int
Encoded memory cache misses.
final
ownedBufferBytesExposed int
Total encoded bytes exposed through owned buffers.
final
ownedBufferHandlesCreated int
owned buffer handles created at the runtime boundary.
final
ownedBufferHandlesFreed int
owned buffer handles released at the runtime boundary.
final
processedDiskCorruptionRecoveries int
Corrupt processed variant disk entries recovered as misses.
final
processedDiskHits int
Processed variant disk cache hits.
final
processedDiskMisses int
Processed variant disk cache misses.
final
processedDiskStaleHits int
Stale processed variant disk entries encountered.
final
processedDiskWrites int
Processed variant disk writes.
final
processedHitRate double
Hit rate for processed variant cache lookups only.
no setter
processedMemoryBytes int
Processed variant bytes retained in the shared memory LRU.
final
processedMemoryEntries int
Processed variant entries retained in the shared memory LRU.
final
processedMemoryEvictions int
Processed variant encoded memory evictions.
final
processedMemoryHits int
Processed variant encoded memory hits.
final
processedMemoryMisses int
Processed variant encoded memory misses.
final
progressEventsDrained int
runtime progress events drained by Dart.
final
progressEventsDropped int
runtime progress events dropped by bounded buffering.
final
progressEventsEmitted int
runtime progress events emitted.
final
progressPreviewBytesDropped int
Progressive preview bytes discarded before delivery to Dart.
final
progressPreviewBytesRetained int
Progressive preview bytes currently retained by runtime sessions.
final
progressPreviewPayloadsDropped int
Progressive preview payloads discarded before delivery to Dart.
final
progressSessionsCreated int
runtime progress sessions created.
final
progressSessionsFreed int
runtime progress sessions released.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staleRevalidatesCompleted int
Stale-while-revalidate background refreshes completed.
final
staleRevalidatesFailed int
Stale-while-revalidate background refreshes failed.
final
staleRevalidatesInFlight int
Stale-while-revalidate refreshes currently in flight.
final
staleRevalidatesSkipped int
Stale-while-revalidate refreshes skipped by policy, dedupe, or backpressure.
final
staleRevalidatesStarted int
Stale-while-revalidate background refreshes started.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited