PixaCacheWarmupManifest class final
Batch prefetch manifest for app startup and offline warmup.
Constructors
-
PixaCacheWarmupManifest(Iterable<
PixaCacheWarmupEntry> entries) - Creates a warmup manifest.
Properties
-
entries
→ List<
PixaCacheWarmupEntry> -
Entries in execution order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
PixaCacheWarmupExecutor executor, {bool continueOnError = true}) → Future< PixaCacheWarmupReport> -
Runs the manifest with
executor. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited