PixaCustomSource class final

Custom image source.

Inheritance

Constructors

PixaCustomSource(String id, PixaCustomSourceLoader loader)
Creates a custom image source.
const

Properties

cacheMaterial Object
Stable source material for cache-key generation.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
Stable custom source identity.
final
loader PixaCustomSourceLoader
Loader used by the default custom fetcher.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeLabel String
Redacted source label safe for logs and observer events.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited