PixaHeadersPolicy class final

Header policy for cache-key participation.

Annotations

Constructors

PixaHeadersPolicy({Set<String> varyHeaders = const <String>{}})
Creates a header policy.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
varyHeaders Set<String>
Headers allowed to affect cache identity.
final

Methods

keyMaterial(Map<String, String> headers) Map<String, Object?>
Returns redacted key material for selected headers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited