PixaPlugin class abstract interface

Pixa plugin contract.

Properties

compatiblePixaVersions PixaVersionConstraint
Compatible core package versions.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Stable plugin id.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(PixaRegistry registry) → void
Registers plugin handlers.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited