PixaProgress class final

Immutable progress event emitted by the Pixa pipeline.

Constructors

PixaProgress({required int requestId, required PixaStage stage, int? receivedBytes, int? expectedBytes, String? message, PixaProgressivePreview? progressivePreview})
Creates a progress event.
const

Properties

expectedBytes int?
Expected byte count when available.
final
fraction double?
Completion ratio when byte counts are known.
no setter
hashCode int
The hash code for this object.
no setterinherited
message String?
Redacted human-readable message.
final
progressivePreview PixaProgressivePreview?
Progressive image preview produced from the same in-flight request.
final
receivedBytes int?
Received byte count when available.
final
requestId int
Request id.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage PixaStage
Current pipeline stage.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited