pixa_debug library
Debug, diagnostics, and runtime observability APIs.
Classes
- PixaCacheStats
- Snapshot of Pixa cache behavior.
- PixaDebugInspector
- Inspector API for debug tooling.
- PixaDebugSnapshot
- Debug snapshot for inspector surfaces and diagnostics.
- PixaDecodedCacheStats
- Snapshot of Flutter decoded image cache behavior.
- PixaDisplayDecoderBackendSnapshot
- Debug snapshot for a registered display decoder backend.
- PixaDisplayDecoderSnapshot
- Debug snapshot describing display decoder backend selection.
- PixaRuntimeCapabilities
- Runtime runtime capability snapshot.
- PixaRuntimeImageFormatCapability
- Runtime support capabilities for one encoded image format.
- PixaRuntimePlatformCheck
- One runtime platform validation check.
- PixaRuntimePlatformContract
- Production platform contract expected from one Flutter target platform.
- PixaRuntimePlatformSelfCheck
- Runtime platform self-check report.
- PixaRuntimePlatformStatus
- platform support and load status.
- PixaRuntimePluginModuleSnapshot
- Immutable runtime plugin module diagnostics.
- PixaRuntimePluginRegistryStats
- runtime plugin host registry counters.
- PixaSchedulerStats
- Snapshot of Dart listener/control scheduler behavior.
Enums
- PixaRuntimePluginDeployment
- Deployment shape for a module registered in the Rust runtime host.
Functions
-
pixaPlatformStatusForProbe(
{required bool isWeb, required TargetPlatform targetPlatform, required bool runtimeAvailable}) → PixaRuntimePlatformStatus - Evaluates platform status from explicit probe inputs.
Typedefs
- PixaRegistryArchitectureSnapshot = PixaRegistryArchitectureSnapshot
- Aggregated registry shape exposed by debug and diagnostics APIs.