completionFrameScheduled property
Whether a frame callback is scheduled to drain pending completions.
Implementation
final bool completionFrameScheduled;
Whether a frame callback is scheduled to drain pending completions.
final bool completionFrameScheduled;