PixaRuntimePlatformCheck class final
One runtime platform validation check.
Constructors
- PixaRuntimePlatformCheck({required String name, required bool passed, required bool required, required String message})
-
Creates a validation check result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable diagnostic message.
final
- name → String
-
Stable check name.
final
- passed → bool
-
Whether the check passed.
final
- required → bool
-
Whether this check is required on the current platform contract.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-like representation for debug tools and platform smoke tests.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited