PixaRuntimePlatformStatus class final

platform support and load status.

Constructors

PixaRuntimePlatformStatus({required String platform, required bool isWeb, required bool isSupportedPlatform, required bool runtimeAvailable, required String message, PixaRuntimePlatformContract? contract})
Creates a platform status snapshot.
const
PixaRuntimePlatformStatus.current()
Returns the current platform/runtime load status.
factory

Properties

contract PixaRuntimePlatformContract?
Platform contract required for this platform, when supported.
final
hashCode int
The hash code for this object.
no setterinherited
isSupportedPlatform bool
Whether Pixa supports this platform.
final
isWeb bool
Whether the current build target is Web.
final
message String
Human-readable status message.
final
platform String
Flutter target platform label.
final
runtimeAvailable bool
Whether runtime symbols are loadable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited