PixaRuntimePluginDeployment enum

Deployment shape for a module registered in the Rust runtime host.

Inheritance
Available extensions

Values

builtInHostModule → const PixaRuntimePluginDeployment

The module is compiled directly into Pixa's runtime host.

hostLinkedPluginModule → const PixaRuntimePluginDeployment

The module is linked into Pixa's host binary at app build time.

assetModule → const PixaRuntimePluginDeployment

The module is loaded through an explicit runtime asset boundary.

external → const PixaRuntimePluginDeployment

The module delegates to a process or platform service.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PixaRuntimePluginDeployment>
A constant List of the values in this enum, in order of their declaration.