PixaBytePayload class final

Payload returned by fetchers, decoders, processors, and cache stores.

Constructors

PixaBytePayload({required Uint8List bytes, PixaPayloadKind kind = PixaPayloadKind.encodedImage, String? mimeType, Map<String, Object?> metadata = const <String, Object?>{}})
Creates a byte payload.
const

Properties

bytes Uint8List
Encoded bytes or a small control payload for non-byte handle kinds.
final
hashCode int
The hash code for this object.
no setterinherited
kind PixaPayloadKind
Payload shape.
final
metadata Map<String, Object?>
Non-sensitive structured metadata.
final
mimeType String?
Optional MIME type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited