PixaCacheHit class final

Cache hit.

Inheritance

Constructors

PixaCacheHit({required PixaBytePayload payload, required bool isStale})
Creates a cache hit.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isStale bool
Whether the entry is expired but still usable for stale paths.
final
payload PixaBytePayload
Cached bytes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited