PixaCacheStoreDescriptor class abstract interface

Encoded cache store extension descriptor.

Implemented types
Implementers

Properties

executionKind PixaPluginExecutionKind
Execution layer used by this cache store.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
no setterinherited
namespace String
Cache store namespace handled by this descriptor.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited