PixaCacheWriteContext class final

Cache write context.

Constructors

PixaCacheWriteContext({required PixaExecutionContext execution, Duration? ttl, bool privateEntry = false})
Creates a cache write context.
const

Properties

execution PixaExecutionContext
Shared execution context.
final
hashCode int
The hash code for this object.
no setterinherited
privateEntry bool
Whether this entry belongs to a private cache partition.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl Duration?
Entry TTL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited