PixaCancellationSignal class abstract interface

Cancellation view passed to plugin handlers.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
isCancellationRequested bool
Whether the caller has cancelled this work.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
whenCancelled Future<void>
Completes when cancellation is requested.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
throwIfCancellationRequested() → void
Throws a typed cancellation failure if cancellation has been requested.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited