PixaDecoder class abstract interface

Decoder execution contract.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(PixaBytePayload input, PixaExecutionContext context) FutureOr<PixaBytePayload>
Decodes or transcodes input for context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited