hotPathSafe property
bool
get
hotPathSafe
True when the decoder can run on gallery hot paths.
Implementation
bool get hotPathSafe {
return stable && zeroCopyInput && ownedOutputBuffers;
}
True when the decoder can run on gallery hot paths.
bool get hotPathSafe {
return stable && zeroCopyInput && ownedOutputBuffers;
}