PixaDecoderDescriptor class abstract interface

Decoder extension descriptor.

Implemented types
Implementers

Properties

capabilities PixaDecoderCapabilities
Decoder capability contract used by routing, docs and validation.
no setter
executionKind PixaPluginExecutionKind
Execution layer used by this decoder.
no setter
formatIds Set<String>
Stable encoded format ids handled by this decoder.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
no setterinherited
mimeTypes Set<String>
MIME types handled by this decoder.
no setter
priority int
Higher priority wins for the same MIME type.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatures List<PixaDecoderSignature>
Bounded-header byte signatures handled by this decoder.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited