PixaDecoderSignature class final

Bounded static signature route for a decoder adapter.

Constructors

PixaDecoderSignature({required int offset, required List<int> magic, required String mimeType, String? formatId})
Creates a bounded-header decoder signature.
const

Properties

formatId String?
Stable encoded format id emitted when this signature matches.
final
hashCode int
The hash code for this object.
no setterinherited
magic List<int>
Magic bytes to compare at offset.
final
mimeType String
MIME type emitted when this signature matches.
final
offset int
Byte offset within the first encoded header bytes.
final
routeKey String
Stable conflict key for registry validation.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(Uint8List bytes) bool
Whether this signature matches bytes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited