PixaFetcherDescriptor class abstract interface

Fetcher extension descriptor.

Implemented types
Implementers

Properties

executionKind PixaPluginExecutionKind
Execution layer used by this fetcher.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceKinds Set<String>
Source kinds handled by this fetcher, such as s3 or content.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited