PixaPayloadKind enum

Encoded bytes returned by fetchers, decoders, processors, and cache stores.

Inheritance
Available extensions

Values

encodedImage → const PixaPayloadKind

Regular encoded image bytes that can enter Pixa encoded caches.

runtimeOwnedBuffer → const PixaPayloadKind

Runtime-owned buffer with explicit lifetime managed by the host runtime.

fileHandle → const PixaPayloadKind

File handle or path-like locator produced by a bounded plugin boundary.

streamHandle → const PixaPayloadKind

Stream handle for large payloads that must avoid Dart isolate copies.

metadataOnly → const PixaPayloadKind

Metadata-only result with no image bytes.

runtimeDisplayFrame → const PixaPayloadKind

Runtime display frame, such as RGBA pixels owned by the runtime.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PixaPayloadKind>
A constant List of the values in this enum, in order of their declaration.