PixaPlatformCacheStoreDescriptor class abstract interface

Cache-store descriptor backed by a Flutter platform plugin boundary.

Implemented types

Properties

cacheStore PixaCacheStore
Cache-store implementation.
no setter
executionKind PixaPluginExecutionKind
Execution layer used by this cache store.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
no setterinherited
namespace String
Cache store namespace handled by this descriptor.
no setterinherited
platform PixaPlatformContract
Platform-channel contract for this descriptor.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited