PixaPlatformDecoderDescriptor class abstract interface

Decoder descriptor backed by a Flutter platform plugin boundary.

Implemented types

Properties

capabilities PixaDecoderCapabilities
Decoder capability contract used by routing, docs and validation.
no setterinherited
decoder PixaDecoder
Decoder implementation.
no setter
executionKind PixaPluginExecutionKind
Execution layer used by this decoder.
no setterinherited
formatIds Set<String>
Stable encoded format ids handled by this decoder.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
no setterinherited
mimeTypes Set<String>
MIME types handled by this decoder.
no setterinherited
platform PixaPlatformContract
Platform-channel contract for this descriptor.
no setterinherited
priority int
Higher priority wins for the same MIME type.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatures List<PixaDecoderSignature>
Bounded-header byte signatures handled by this decoder.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited