PixaPlatformFetcherDescriptor class abstract interface

Fetcher descriptor backed by a Flutter platform plugin boundary.

Implemented types

Properties

executionKind PixaPluginExecutionKind
Execution layer used by this fetcher.
no setterinherited
fetcher PixaFetcher
Fetcher implementation.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
no setterinherited
platform PixaPlatformContract
Platform-channel contract for this descriptor.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceKinds Set<String>
Source kinds handled by this fetcher, such as s3 or content.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited