PixaProcessorDescriptor class abstract interface

Processor extension descriptor.

Implemented types
Implementers

Properties

executionKind PixaPluginExecutionKind
Execution layer used by this processor.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
no setterinherited
operations Set<String>
Stable processor operation names.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited