decodersWithMetadataProbe property
Decoders that can parse bounded encoded metadata before full decode.
Implementation
final int decodersWithMetadataProbe;
Decoders that can parse bounded encoded metadata before full decode.
final int decodersWithMetadataProbe;