hostLinkedPluginModules property
Unique modules linked into the final host binary at app build time.
Implementation
final int hostLinkedPluginModules;
Unique modules linked into the final host binary at app build time.
final int hostLinkedPluginModules;