PixaRuntimeCacheStoreDescriptor class final

Descriptor for Pixa's built-in Rust-backed image cache store.

Implemented types

Constructors

PixaRuntimeCacheStoreDescriptor({String id = pixaCacheStoreDescriptorId, String namespace = pixaCacheStoreNamespace, PixaCacheStoreEngine engine = PixaCacheStoreEngine.rustRuntime, PixaCacheStoreCapabilities capabilities = const PixaCacheStoreCapabilities.runtimeImageCache(), PixaRuntimeContract runtime = const PixaRuntimeContract.builtInHostModule(moduleId: 'pixa.cache_store')})
Creates a runtime cache-store descriptor.
const

Properties

capabilities PixaCacheStoreCapabilities
Production capabilities guaranteed by this store contract.
final
engine PixaCacheStoreEngine
Store engine backing this descriptor.
final
executionKind PixaPluginExecutionKind
Execution layer used by this cache store.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
final
namespace String
Cache store namespace handled by this descriptor.
final
runtime PixaRuntimeContract
Runtime ABI contract for this descriptor.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited