PixaRuntimeDeployment enum

Runtime ABI deployment mode for a plugin module.

Inheritance
Available extensions

Values

builtInHostModule → const PixaRuntimeDeployment

The module is compiled into Pixa's host runtime.

hostLinkedPluginModule → const PixaRuntimeDeployment

A third-party module linked into Pixa's host binary at app build time.

assetModule → const PixaRuntimeDeployment

The module is supplied by an asset-module dynamic library.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PixaRuntimeDeployment>
A constant List of the values in this enum, in order of their declaration.