PixaRuntimeDescriptor class abstract interface

Descriptor that executes through the runtime ABI.

Implemented types
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
no setterinherited
runtime PixaRuntimeContract
Runtime ABI contract for this descriptor.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited