PixaScheduler class abstract interface

Scheduler execution contract for plugin-provided queues.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
schedule<T>(PixaRequest request, Future<T> operation(PixaExecutionContext context), PixaExecutionContext context) Future<T>
Enqueues operation according to request priority and limits.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited