PixaVideoFrameBackendDescriptor class abstract interface

Explicit video-frame fetcher descriptor.

Implemented types
Implementers

Properties

backendId String?
Optional backend route. null claims the default video-frame route.
no setter
capabilities PixaVideoFrameBackendCapabilities
Video-frame extraction capabilities.
no setter
executionKind PixaPluginExecutionKind
Execution layer used by this fetcher.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Stable handler id.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceKinds Set<String>
Source kinds handled by this fetcher, such as s3 or content.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited