PixaCacheWarmupReport class final
Summary produced after running a warmup manifest.
Constructors
-
PixaCacheWarmupReport({required int totalCount, required List<
String> succeededIds, required List<PixaCacheWarmupFailure> failures, required bool stoppedAfterFailure, required Duration duration}) -
Creates a warmup report.
const
Properties
- duration → Duration
-
Total execution duration.
final
- failureCount → int
-
Number of failed entries.
no setter
-
failures
→ List<
PixaCacheWarmupFailure> -
Failed entries.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
Whether all entries were warmed.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stoppedAfterFailure → bool
-
Whether execution stopped because
continueOnErrorwas false.final -
succeededIds
→ List<
String> -
Successful entry ids.
final
- successCount → int
-
Number of successful entries.
no setter
- totalCount → int
-
Number of manifest entries.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited