PixaConfig class final
Global Pixa configuration.
Constructors
-
PixaConfig({int memoryCacheBytes = 96 * 1024 * 1024, int diskCacheBytes = 512 * 1024 * 1024, int networkConcurrency = 6, int decodeConcurrency = 2, int maxImageCompletionsPerFrame = 4, int maxQueuedRuntimeLoads = 2048, int maxQueuedDecodes = 128, int? decodedCacheMaximumSize, int? decodedCacheMaximumSizeBytes, String? cacheRootPath, List<
PixaPlugin> plugins = const <PixaPlugin>[], List<PixaObserver> observers = const <PixaObserver>[], PixaObserverSamplingPolicy observerSamplingPolicy = PixaObserverSamplingPolicy.none}) -
Creates a Pixa configuration.
const
Properties
- cacheRootPath → String?
-
Optional platform cache root override.
final
- decodeConcurrency → int
-
Flutter decode concurrency budget.
final
- decodedCacheMaximumSize → int?
-
Optional Flutter decoded image cache entry budget.
final
- decodedCacheMaximumSizeBytes → int?
-
Optional Flutter decoded image cache byte budget.
final
- diskCacheBytes → int
-
Rust disk cache budget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxImageCompletionsPerFrame → int
-
Maximum decoded image completions released to Flutter in one frame.
final
- maxQueuedDecodes → int
-
Maximum Flutter display decodes allowed to wait behind active decodes.
final
- maxQueuedRuntimeLoads → int
-
Maximum runtime loads allowed to wait behind active runtime work.
final
- memoryCacheBytes → int
-
Rust encoded memory cache budget.
final
- networkConcurrency → int
-
Runtime network concurrency budget.
final
-
observers
→ List<
PixaObserver> -
Observers registered during configure.
final
- observerSamplingPolicy → PixaObserverSamplingPolicy
-
Sampling policy applied before observer delivery.
final
-
plugins
→ List<
PixaPlugin> -
Plugins registered during configure.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited