PixaObserverSamplingPolicy class final
Observer sampling policy for high-frequency event streams.
Constructors
- PixaObserverSamplingPolicy({Duration progressInterval = Duration.zero, int progressSampleRate = 1})
-
Creates an observer sampling policy.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- progressInterval → Duration
-
Minimum interval between progress events for the same request.
final
- progressSampleRate → int
-
Deliver every Nth progress event after interval filtering.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplesProgress → bool
-
Whether this policy may drop progress events.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- none → const PixaObserverSamplingPolicy
- No sampling; every event is delivered.