PixaPipelineHandle class final
Cancellable listener handle for a scheduled pipeline load.
Properties
-
future
→ Future<
PixaPipelineLoad> -
Future for this listener.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId → int
-
Listener request id.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → void - Releases this listener from the in-flight runtime load.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited