PixaRequestSnapshot class final
Redacted request payload safe for observers, logs, and debug panels.
Constructors
- PixaRequestSnapshot.fromRequest(PixaRequest request)
- Creates a redacted request snapshot.
Properties
- allowCrossHostRedirects → bool
-
Whether cross-host redirects are allowed.
final
- allowHttpsToHttpRedirect → bool
-
Whether HTTPS to HTTP redirects are allowed.
final
- cacheKey → String
-
Stable hashed cache key.
final
- cacheMode → String
-
Cache mode.
final
- cacheNamespace → String
-
Cache namespace.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Redacted request headers.
final
- maxAttempts → int
-
Maximum retry attempts.
final
- priority → String
-
Scheduler priority.
final
- retryMode → String
-
Retry mode.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
Image scale.
final
- sourceLabel → String
-
Redacted source label.
final
- targetHeight → int?
-
Target decode height.
final
- targetWidth → int?
-
Target decode width.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-like representation for logging.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited