PixaDebugSnapshot class final
Debug snapshot for inspector surfaces and diagnostics.
Constructors
-
PixaDebugSnapshot({required bool isConfigured, required PixaConfig config, required PixaDisplayDecoderSnapshot displayDecoder, required PixaRuntimeCapabilities capabilities, required PixaRuntimePlatformSelfCheck platformSelfCheck, required PixaRegistryArchitectureSnapshot registryArchitecture, required Map<
String, Object?> registryRoutePlan, required PixaCacheStats? cacheStats, required PixaDecodedCacheStats decodedCacheStats, int decodedRegistryEntries = 0, required PixaSchedulerStats? schedulerStats}) -
Creates a debug snapshot.
const
Properties
- cacheStats → PixaCacheStats?
-
runtime cache statistics, when Pixa is configured.
final
- capabilities → PixaRuntimeCapabilities
-
runtime capability snapshot.
final
- config → PixaConfig
-
Current public configuration.
final
- decodedCacheStats → PixaDecodedCacheStats
-
Flutter decoded image cache statistics.
final
- decodedRegistryEntries → int
-
Provider keys retained for request and namespace eviction.
final
- displayDecoder → PixaDisplayDecoderSnapshot
-
Display decoder selector and backend snapshot.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConfigured → bool
-
Whether Pixa is configured.
final
- platformSelfCheck → PixaRuntimePlatformSelfCheck
-
Runtime platform self-check report.
final
- registryArchitecture → PixaRegistryArchitectureSnapshot
-
Plugin registry and runtime module architecture snapshot.
final
-
registryRoutePlan
→ Map<
String, Object?> -
Compiled plugin route plan used by hot-path lookups.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedulerStats → PixaSchedulerStats?
-
Scheduler statistics, when Pixa is configured.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticString(
) → String - Compact redacted diagnostic text for issue reports and support logs.
-
toJson(
) → Map< String, Object?> - JSON-like representation for debug UIs.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited