PixaDisplayDecoderBackendSnapshot class final
Debug snapshot for a registered display decoder backend.
Constructors
Properties
- execution → String
-
Execution boundary, for example
flutterorruntime.final - hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable backend id.
final
- ownsPipeline → bool
-
Whether this backend owns network/cache/scheduler pipeline work.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamKind → String
-
Stream shape produced by this backend.
final
- supportsAnimatedImages → bool
-
Whether this backend supports animated image streams.
final
- usesFlutterEngine → bool
-
Whether this backend ultimately uses Flutter engine image decode.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-like representation for debug UIs.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited