PixaDisplayDecoderSnapshot class final
Debug snapshot describing display decoder backend selection.
Constructors
-
PixaDisplayDecoderSnapshot({required String selector, required String defaultBackend, required bool hasRuntimeDisplayBackend, required int completionQueueDepth, required int completionsReleasedThisFrame, required bool completionFrameScheduled, required List<
PixaDisplayDecoderBackendSnapshot> backends}) -
Creates a display decoder snapshot.
const
Properties
-
backends
→ List<
PixaDisplayDecoderBackendSnapshot> -
Registered display backends.
final
- completionFrameScheduled → bool
-
Whether a frame callback is scheduled to drain pending completions.
final
- completionQueueDepth → int
-
Pending decoded image completions waiting for frame-paced delivery.
final
- completionsReleasedThisFrame → int
-
Number of image completions already released in the current frame.
final
- defaultBackend → String
-
Backend selected for the default request path.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasRuntimeDisplayBackend → bool
-
Whether a runtime display backend is currently registered.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector → String
-
Stable selector identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-like representation for debug UIs.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited