PixaRuntimeCapabilities class final
Runtime runtime capability snapshot.
Constructors
-
PixaRuntimeCapabilities({required bool diskCache, required bool httpTransport, required bool exifParser, required bool pixelProcessors, int? runtimePluginAbiVersion, PixaRuntimePluginRegistryStats runtimePluginRegistryStats = const PixaRuntimePluginRegistryStats.empty(), List<
PixaRuntimeImageFormatCapability> imageFormats = const <PixaRuntimeImageFormatCapability>[], PixaRuntimePlatformStatus platformStatus = const PixaRuntimePlatformStatus(platform: 'unknown', isWeb: false, isSupportedPlatform: false, runtimeAvailable: false, message: 'Pixa platform status has not been probed.')}) -
Creates a capability snapshot.
const
- PixaRuntimeCapabilities.current()
-
Reads capabilities from the runtime bridge.
factory
Properties
- diskCache → bool
-
Rust-backed disk cache is available.
final
- exifParser → bool
-
Rust-backed EXIF parser is available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasRequiredCore → bool
-
True when the mandatory runtime core is loaded.
no setter
- httpTransport → bool
-
Rust-backed HTTP transport is available.
final
-
imageFormats
→ List<
PixaRuntimeImageFormatCapability> -
Runtime image format support matrix.
final
- pixelProcessors → bool
-
Rust-backed pixel processors are available.
final
- platformStatus → PixaRuntimePlatformStatus
-
Platform and runtime library load status.
final
- runtimePluginAbiVersion → int?
-
runtime plugin host ABI version when runtime symbols are available.
final
- runtimePluginRegistryStats → PixaRuntimePluginRegistryStats
-
runtime plugin host registry counters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited