PixaRuntimeImageFormatCapability class final
Runtime support capabilities for one encoded image format.
Constructors
- PixaRuntimeImageFormatCapability({required PixaImageMetadataFormat format, required bool sniffing, required bool metadata, required bool engineDisplay, required bool runtimeDisplay, required bool processorDecode, required bool animated, required bool defaultRuntimeDisplay, required bool regionDecode})
-
Creates one image format capability entry.
const
Properties
- animated → bool
-
Pixa supports an animated display mode for this format.
final
- defaultRuntimeDisplay → bool
-
Ordinary display requests automatically choose runtime display.
final
- engineDisplay → bool
-
Flutter engine display backend supports this format by default.
final
- format → PixaImageMetadataFormat
-
Encoded image format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → bool
-
Runtime can parse dimensions/traits for this format.
final
- processorDecode → bool
-
Runtime processor input decode can use this format.
final
- regionDecode → bool
-
Runtime decoder can read a bounded region without full-frame decode.
final
- runtimeDisplay → bool
-
Runtime RGBA display backend can decode this format for static output.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sniffing → bool
-
Runtime can identify this format from bounded magic/header bytes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-like representation for debug tools.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited