PixaRuntimePlatformSelfCheck class final
Runtime platform self-check report.
Constructors
-
PixaRuntimePlatformSelfCheck({required String platform, required bool isWeb, required bool isSupportedPlatform, required bool passed, required List<
PixaRuntimePlatformCheck> checks}) -
Creates a platform self-check report.
const
- PixaRuntimePlatformSelfCheck.evaluate({required PixaRuntimeCapabilities capabilities, required String? cacheRootPath})
-
Evaluates runtime platform checks from the current capability snapshot.
factory
Properties
-
checks
→ List<
PixaRuntimePlatformCheck> -
Individual check results.
final
-
failedChecks
→ Iterable<
PixaRuntimePlatformCheck> -
Required checks that failed.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSupportedPlatform → bool
-
Whether Pixa supports this platform.
final
- isWeb → bool
-
Whether this report is for Web.
final
- passed → bool
-
Whether every required check passed.
final
- platform → String
-
Platform label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-like representation for debug tools and platform smoke tests.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited