PixaRuntimePluginRegistryStats class final
runtime plugin host registry counters.
Constructors
-
PixaRuntimePluginRegistryStats({required int modules, required int builtInModules, required int hostLinkedModules, required int assetModules, required int linkableModules, required int fetchers, required int videoFrameFetchers, required int videoFrameEncodedOutputFetchers, required List<
String> videoFrameSourceKinds, required List<String> videoFrameOutputMimeTypes, required int decoders, required int processors, required int cacheStores, List<PixaRuntimePluginModuleSnapshot> moduleSnapshots = const <PixaRuntimePluginModuleSnapshot>[]}) - Creates a runtime plugin registry stats snapshot.
- PixaRuntimePluginRegistryStats.decode(Uint8List bytes)
-
Decodes the internal
PXM2binary diagnostics payload.factory - PixaRuntimePluginRegistryStats.empty()
-
Empty registry stats.
const
Properties
- assetModules → int
-
Asset modules loaded through a separate boundary.
final
- builtInModules → int
-
Built-in host modules.
final
- cacheStores → int
-
runtime cache-store capabilities.
final
- canUseSingleHostBinary → bool
-
True when the registry does not require additional runtime binaries.
no setter
- decoders → int
-
runtime decoder capabilities.
final
- fetchers → int
-
runtime fetcher capabilities.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostLinkedModules → int
-
Host-linked modules folded into the final runtime binary.
final
- linkableModules → int
-
Modules that can share one final runtime host binary.
final
- modules → int
-
Unique runtime plugin modules registered in the host.
final
-
moduleSnapshots
→ List<
PixaRuntimePluginModuleSnapshot> -
Runtime modules in stable module-id order.
final
- processors → int
-
runtime processor capabilities.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoFrameEncodedOutputFetchers → int
-
runtime video-frame fetchers that declare encoded image output.
final
- videoFrameFetchers → int
-
runtime video-frame fetcher capabilities.
final
-
videoFrameOutputMimeTypes
→ List<
String> -
Encoded image MIME types that runtime video-frame backends may output.
final
-
videoFrameSourceKinds
→ List<
String> -
Runtime video-frame source kinds registered in the host.
final
Methods
-
moduleById(
String moduleId) → PixaRuntimePluginModuleSnapshot? -
Returns the runtime module with
moduleId, when registered. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-like representation for debug surfaces.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited