PixaSchedulerStats class final
Snapshot of Dart listener/control scheduler behavior.
Constructors
- PixaSchedulerStats({required int maxConcurrentRuntimeLoads, required int maxQueuedRuntimeLoads, required int activeRuntimeLoads, required int queueDepth, required int inflightRequests, required int listeners, required int totalQueued, required int totalStarted, required int totalCoalesced, required int totalCompleted, required int totalFailed, required int totalCancelled, required int totalBackpressureDropped, required int runtimeProgressEvents, required int runtimeProgressEventsDropped, required int observerEventsDroppedBySampling, int dartToRuntimeInputCopies = 0, int dartToRuntimeInputBytesCopied = 0})
-
Creates a scheduler stats snapshot.
const
Properties
- activeRuntimeLoads → int
-
runtime loads currently active.
final
- dartToRuntimeInputBytesCopied → int
-
Total bytes copied from Dart-owned input buffers into runtime call memory.
final
- dartToRuntimeInputCopies → int
-
Number of Dart-owned input buffers copied into runtime call memory.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inflightRequests → int
-
In-flight root requests, including queued and active.
final
- listeners → int
-
Active listeners attached to in-flight requests.
final
- maxConcurrentRuntimeLoads → int
-
Configured Dart isolate entries into runtime load calls.
final
- maxQueuedRuntimeLoads → int
-
Configured root runtime loads allowed to wait behind active work.
final
- observerEventsDroppedBySampling → int
-
Observer events dropped by Dart sampling policy.
final
- queueDepth → int
-
Queued root requests.
final
- runtimeProgressEvents → int
-
runtime progress events delivered to listeners.
final
- runtimeProgressEventsDropped → int
-
runtime progress events reported dropped by runtime bounded buffering.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBackpressureDropped → int
-
Total root/listener work dropped or rejected by scheduler backpressure.
final
- totalCancelled → int
-
Total listeners cancelled.
final
- totalCoalesced → int
-
Total listeners coalesced onto existing root requests.
final
- totalCompleted → int
-
Total listeners completed successfully.
final
- totalFailed → int
-
Total listeners failed.
final
- totalQueued → int
-
Total root requests queued.
final
- totalStarted → int
-
Total root requests started.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-like representation for debug UIs.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited