Cache-store execution contract.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearNamespace(
String namespace) → FutureOr< void> - Clears one namespace.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String namespace, String key, PixaExecutionContext context) → FutureOr< PixaCacheLookup> - Reads one entry.
-
remove(
String namespace, String key) → FutureOr< void> - Removes one entry.
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
String namespace, String key, PixaBytePayload payload, PixaCacheWriteContext context) → FutureOr< void> - Writes one entry.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited