PixaControllerHook class abstract
Controller lifecycle hook base class for plugins.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAttach(
PixaRequest request) → void - Called when a controller attaches.
-
onDetach(
PixaRequest request) → void - Called when a controller detaches.
-
onDispose(
PixaRequest request) → void - Called when a controller is disposed.
-
onVisibilityChanged(
PixaRequest request, {required bool visible}) → void - Called when visibility changes.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited