PixaExecutionContext class final
Immutable execution context shared by plugin handlers.
Constructors
- PixaExecutionContext({required int requestId, required PixaRequest request, required PixaCancellationSignal cancellationSignal, PixaProgressSink? onProgress})
-
Creates an execution context.
const
Properties
- cancellationSignal → PixaCancellationSignal
-
Cancellation signal shared by this handler invocation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onProgress → PixaProgressSink?
-
Optional progress sink.
final
- request → PixaRequest
-
Request being executed.
final
- requestId → int
-
Request id scoped to this pipeline execution.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
emit(
PixaProgress progress) → void -
Emits
progressif a sink is attached. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited