PixaManualCancellationSignal class final
Simple cancellation signal for tests and non-runtime plugin handlers.
- Implemented types
Constructors
- PixaManualCancellationSignal()
- Creates a manual cancellation signal.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancellationRequested → bool
-
Whether the caller has cancelled this work.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
whenCancelled
→ Future<
void> -
Completes when cancellation is requested.
no setteroverride
Methods
-
cancel(
) → void - Requests cancellation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
throwIfCancellationRequested(
) → void -
Throws a typed cancellation failure if cancellation has been requested.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited