PixaPluginIntegrationSelection class final
Selected adaptive integration recorded during registry setup.
Constructors
- PixaPluginIntegrationSelection({required String pluginId, required String candidateId, required PixaPluginIntegrationMode mode, required int priority, String? packageName})
-
Creates a selected integration descriptor.
const
Properties
- candidateId → String
-
Selected candidate id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → PixaPluginIntegrationMode
-
Selected integration mode.
final
- packageName → String?
-
Pub package that provided the selected candidate.
final
- pluginId → String
-
Plugin id passed to PixaRegistry.registerAdaptiveIntegration.
final
- priority → int
-
Selected candidate priority.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-like representation for diagnostics and debug panels.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited