PixaProcessorContext class final
Processor-specific execution context.
Constructors
-
PixaProcessorContext({required PixaExecutionContext execution, required String operation, Map<
String, Object?> arguments = const <String, Object?>{}}) -
Creates a processor context.
const
Properties
-
arguments
→ Map<
String, Object?> -
Processor arguments.
final
- execution → PixaExecutionContext
-
Shared execution context.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- operation → String
-
Stable processor operation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited