PixaRegistry class final
Mutable plugin registration surface used during Pixa.configure.
Constructors
- PixaRegistry()
- Creates a registry.
Properties
-
adaptiveIntegrationSelections
→ List<
PixaPluginIntegrationSelection> -
Selected adaptive pub plugin integrations.
no setter
-
cacheKeyContributors
→ List<
PixaCacheKeyContributorDescriptor> -
Registered cache-key contributors.
no setter
-
cacheStores
→ List<
PixaCacheStoreDescriptor> -
Registered cache stores.
no setter
-
debugPanels
→ List<
PixaDebugPanelDescriptor> -
Registered debug panels.
no setter
-
decoders
→ List<
PixaDecoderDescriptor> -
Registered decoders.
no setter
-
fetchers
→ List<
PixaFetcherDescriptor> -
Registered fetchers.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
observers
→ List<
PixaObserver> -
Registered observers.
no setter
-
processors
→ List<
PixaProcessorDescriptor> -
Registered processors.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
videoFrameBackends
→ List<
PixaVideoFrameBackendDescriptor> -
Registered video-frame backends.
no setter
Methods
-
architectureSnapshot(
) → PixaRegistryArchitectureSnapshot - Returns an aggregated architecture snapshot for this registry.
-
compileRoutePlan(
) → PixaCompiledRoutePlan - Compiles deterministic route and capability tables for hot-path lookup.
-
decoderForFormatId(
String formatId) → PixaDecoderDescriptor? -
Returns the highest-priority decoder descriptor for
formatId, if any. -
decoderForMimeType(
String mimeType) → PixaDecoderDescriptor? -
Returns the highest-priority decoder descriptor for
mimeType, if any. -
decoderForPayload(
Uint8List bytes, {String? formatId, String? mimeType}) → PixaDecoderDescriptor? - Returns the best decoder route for explicit hints or encoded payload.
-
decoderForSignature(
Uint8List bytes) → PixaDecoderDescriptor? -
Returns the highest-priority decoder descriptor matching
bytes. -
fetcherForSourceKind(
String sourceKind) → PixaFetcherDescriptor? -
Returns the fetcher descriptor registered for
sourceKind, if any. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processorForOperation(
String operation) → PixaProcessorDescriptor? -
Returns the processor descriptor registered for
operation, if any. -
registerAdaptiveIntegration(
{required String pluginId, required List< PixaPluginIntegrationCandidate> candidates, bool requireAvailableCandidate = true}) → void - Selects and registers exactly one integration path for a pub plugin.
-
registerCacheKeyContributor(
PixaCacheKeyContributorDescriptor contributor) → void - Registers a cache-key contributor descriptor.
-
registerCacheStore(
PixaCacheStoreDescriptor cacheStore) → void - Registers a cache store descriptor.
-
registerDebugPanel(
PixaDebugPanelDescriptor panel) → void - Registers a debug panel descriptor.
-
registerDecoder(
PixaDecoderDescriptor decoder) → void - Registers a decoder descriptor.
-
registerFetcher(
PixaFetcherDescriptor fetcher) → void - Registers a fetcher descriptor.
-
registerObserver(
PixaObserver observer) → void - Registers an observer.
-
registerProcessor(
PixaProcessorDescriptor processor) → void - Registers a processor descriptor.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited