PixaRuntimeVideoFrameBackendDescriptor class final
Runtime ABI video-frame backend descriptor.
- Implemented types
Constructors
- PixaRuntimeVideoFrameBackendDescriptor({required String id, required PixaRuntimeContract runtime, String? backendId, PixaVideoFrameBackendCapabilities capabilities = const PixaVideoFrameBackendCapabilities.encodedImage(outputMimeTypes: <String>{'image/png'})})
-
Creates a runtime video-frame backend descriptor.
const
Properties
- backendId → String?
-
Optional backend route.
nullclaims the defaultvideo-frameroute.final - capabilities → PixaVideoFrameBackendCapabilities
-
Video-frame extraction capabilities.
final
- executionKind → PixaPluginExecutionKind
-
Execution layer used by this fetcher.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Stable handler id.
final
- runtime → PixaRuntimeContract
-
Runtime ABI contract for this descriptor.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceKinds
→ Set<
String> -
Source kinds handled by this fetcher, such as
s3orcontent.no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited